package com.fr.plugin.http;

import com.fr.decision.fun.impl.BaseHttpHandler;
import com.fr.json.JSONObject;
import com.fr.plugin.MyDecisionDBAccessProvider;
import com.fr.plugin.config.MyConfig;
import com.fr.plugin.dao.MyDao;
import com.fr.plugin.entity.MyEntity;
import com.fr.stable.db.accessor.DBAccessor;
import com.fr.third.springframework.web.bind.annotation.RequestMethod;
import com.fr.web.utils.WebUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.UUID;

public class AddApi extends BaseHttpHandler {
    @Override
    public RequestMethod getMethod() {
        return null;
    }

    @Override
    public String getPath() {
        return "/add";
    }

    @Override
    public boolean isPublic() {
        return true;
    }

    @Override
    public void handle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse) throws Exception {
        DBAccessor dbAccessor = MyDecisionDBAccessProvider.getDbAccessor();
        //通过这两个函数获取的参数可以避免中文乱码和空指针
        String userName = WebUtils.getHTTPRequestParameter(httpServletRequest, "userName");
        Integer source = WebUtils.getHTTPRequestIntParameter(httpServletRequest, "source");
        //使用配置
        MyConfig myConfig = MyConfig.getInstance();
        Integer minSource = myConfig.getMinSource();
        Integer maxSource = myConfig.getMaxSource();

        //参数校验
        if(source<minSource){
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("msg", "add source fail ,source lees than "+minSource);
            jsonObject.put("code", 100);
            WebUtils.printAsJSON(httpServletResponse, jsonObject);
            return;
        }

        if(source>maxSource){
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("msg", "add source fail ,source bigger than "+maxSource);
            jsonObject.put("code", 101);
            WebUtils.printAsJSON(httpServletResponse, jsonObject);
            return;
        }
        MyEntity myEntity = new MyEntity();
        myEntity.setSource(source);
        myEntity.setUserName(userName);
        myEntity.setId(UUID.randomUUID().toString());
        myEntity.setCreateTime(new Date());

        //执行新增操作
        dbAccessor.runDMLAction(daoContext -> {
            daoContext.getDAO(MyDao.class).add(myEntity);
            return null;
        });
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("msg", "success");
        jsonObject.put("code", 200);
        WebUtils.printAsJSON(httpServletResponse, jsonObject);
    }
}
